/* GnoBang: (c) 2008 by Andreas S. Krebs
 * 
 * This file is part of GnoBang.
 *
 * GnoBang is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GnoBang is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GnoBang.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "gnobang.h"

#include "pixmaps/stonecursor.xbm"
#include "pixmaps/stonecursor_mask.xbm"

#define CURSOR_HOT_X	7
#define CURSOR_HOT_Y	8

/* some local variables */

static GdkBitmap	*stonePixmap=NULL;
static GdkBitmap	*stone_maskPixmap=NULL;
static GdkCursor	*playerCursor[2]={ NULL, NULL };
static GdkCursor	*waitCursor=NULL;


/************************************************************************
 *																		*
 * change the cursor for the drawing area							 	*
 *  																	*
 ************************************************************************/

void setCursor(int nr)
{  
	GdkCursor	*cursor;
	
	if(nr==GAME_FINISHED)
		cursor=waitCursor;    
	else if(goGame->Player[nr].Type==PLAYER_HUMAN)
		cursor=playerCursor[nr];      
	else
		cursor=waitCursor;

	gdk_window_set_cursor(gnoBang->drawingArea->window, cursor);
}


/************************************************************************
 *																		*
 * create the cursors for the drawing area							 	*
 *  																	*
 ************************************************************************/

void createCursors()
{
	GdkWindow	*win=gnoBang->drawingArea->window;
	guint32		topCol, col, botCol;
	GdkColor	fg, bg;

	/* delete cursor if already allocated */
	destroyCursors();
	
	stonePixmap=gdk_bitmap_create_from_data(win, stonecursor_bits, stonecursor_width, stonecursor_height);
	stone_maskPixmap=gdk_bitmap_create_from_data(win, stonecursor_mask_bits, stonecursor_mask_width, stonecursor_mask_height);

	getShadowColors(goGame->Player[0].Color, &topCol, &col, &botCol);
	setGdkColor(gnoBang->drawingArea, &fg, col);
	setGdkColor(gnoBang->drawingArea, &bg, topCol);
    		
	playerCursor[0]=gdk_cursor_new_from_pixmap(stonePixmap, stone_maskPixmap, &fg, &bg, CURSOR_HOT_X, CURSOR_HOT_Y);

	getShadowColors(goGame->Player[1].Color, &topCol, &col, &botCol);
	setGdkColor(gnoBang->drawingArea, &fg, col);
	setGdkColor(gnoBang->drawingArea, &bg, topCol);
    		
	playerCursor[1]=gdk_cursor_new_from_pixmap(stonePixmap, stone_maskPixmap, &fg, &bg, CURSOR_HOT_X, CURSOR_HOT_Y);
  
	waitCursor=gdk_cursor_new(GDK_WATCH);
}


/************************************************************************
 *																		*
 * free all cursors 												 	*
 *  																	*
 ************************************************************************/

void destroyCursors()
{
	if(playerCursor[0])
		gdk_cursor_unref(playerCursor[0]);
	if(playerCursor[1])
		gdk_cursor_unref(playerCursor[1]);
	if(waitCursor)
		gdk_cursor_unref(waitCursor);

	if(stone_maskPixmap)
		gdk_bitmap_unref(stone_maskPixmap);
	if(stonePixmap)
		gdk_bitmap_unref(stonePixmap);
	
	playerCursor[0]=playerCursor[1]=waitCursor=NULL;
	stone_maskPixmap=stonePixmap=NULL;
}
