/* GnoBang: (c) 2008 by Andreas S. Krebs
 * 
 * This file is part of GnoBang.
 *
 * GnoBang is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GnoBang is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GnoBang.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "gnobang.h"

/* local prototypes */
static int initUI();

/* global variables  */
GoGame	*goGame;
GnoBang *gnoBang;


/************************************************************************
 *																		*
 * main - init everything and show window							 	*
 *  																	*
 ************************************************************************/

int main(int argc, char **argv)
{
	int     rc=1;

	gtk_init(&argc, &argv);
	soundSystemInit(&argc, &argv);
	
	goGame=g_slice_new(GoGame);
	loadPrefs();
	
	gnoBang=g_slice_new(GnoBang);

	rc=initUI();
	if(rc)
		goto cleanup;
  
	applyPreferences();
	
	gtk_widget_show(GTK_WIDGET(gnoBang->window));

	gtk_main();

cleanup:
  	if(gnoBang)
  		g_slice_free(GnoBang, gnoBang);

  	if(goGame)
  	{
  		savePrefs();
  		g_slice_free(GoGame, goGame);
  	}
  	
  	return rc;
}


/************************************************************************
 *																		*
 * load UI and get all needed widgets								 	*
 *  																	*
 ************************************************************************/

static int initUI()
{
	GtkBuilder  *builder;
	GError      *err=NULL;

	builder=gtk_builder_new();
	if(gtk_builder_add_from_file(builder, GNOBANG_UI, &err)==0)
	{
		showErrorMessage(err->message);
		g_error_free(err);
		return 1; 
	}

	gnoBang->window=GTK_WINDOW(gtk_builder_get_object(builder, "gnobangWindow"));
	gnoBang->mainBox=GTK_VBOX(gtk_builder_get_object(builder, "mainBox"));
	gnoBang->drawingArea=GTK_WIDGET(gtk_builder_get_object(builder, "bangDrawingArea"));
	gnoBang->playerTimer[0]=GTK_LABEL(gtk_builder_get_object(builder, "player1Timer"));
	gnoBang->playerTimer[1]=GTK_LABEL(gtk_builder_get_object(builder, "player2Timer"));
	gnoBang->playerTimerLabel[0]=GTK_LABEL(gtk_builder_get_object(builder, "player1TimerLabel"));
	gnoBang->playerTimerLabel[1]=GTK_LABEL(gtk_builder_get_object(builder, "player2TimerLabel"));
	gnoBang->toMoveLabel=GTK_LABEL(gtk_builder_get_object(builder, "toMoveLabel"));
	gnoBang->prefsMenuAction=GTK_ACTION(gtk_builder_get_object(builder, "preferencesMenuItem"));
	gnoBang->controlImage=GTK_IMAGE(gtk_builder_get_object(builder, "controlImage"));
	gnoBang->controlLabel=GTK_LABEL(gtk_builder_get_object(builder, "controlLabel"));
	gnoBang->hintButton=GTK_BUTTON(gtk_builder_get_object(builder, "hintButton"));
	gnoBang->undoButton=GTK_BUTTON(gtk_builder_get_object(builder, "undoButton"));
	gnoBang->redoButton=GTK_BUTTON(gtk_builder_get_object(builder, "redoButton"));
   
	gnoBang->prefDiag=GTK_DIALOG(gtk_builder_get_object(builder, "preferencesDialog"));
	gnoBang->columnsButton=GTK_SPIN_BUTTON(gtk_builder_get_object(builder, "columnsButton"));
	gnoBang->rowsButton=GTK_SPIN_BUTTON(gtk_builder_get_object(builder, "rowsButton"));
	gnoBang->firstMoveBox=GTK_COMBO_BOX(gtk_builder_get_object(builder, "firstMoveComboBox"));
	gnoBang->cheatModeBox=GTK_COMBO_BOX(gtk_builder_get_object(builder, "cheatModeComboBox"));
	gnoBang->soundCheckButton=GTK_CHECK_BUTTON(gtk_builder_get_object(builder, "soundCheckButton"));
	gnoBang->playerTypeBox[0]=GTK_COMBO_BOX(gtk_builder_get_object(builder, "player1TypeComboBox"));
	gnoBang->playerNameField[0]=GTK_ENTRY(gtk_builder_get_object(builder, "player1NameField"));
	gnoBang->playerStrategyBox[0]=GTK_COMBO_BOX(gtk_builder_get_object(builder, "player1StrategyComboBox"));
	gnoBang->playerTypeBox[1]=GTK_COMBO_BOX(gtk_builder_get_object(builder, "player2TypeComboBox"));
	gnoBang->playerNameField[1]=GTK_ENTRY(gtk_builder_get_object(builder, "player2NameField"));
	gnoBang->playerStrategyBox[1]=GTK_COMBO_BOX(gtk_builder_get_object(builder, "player2StrategyComboBox"));
	gnoBang->boardColorButton=GTK_COLOR_BUTTON(gtk_builder_get_object(builder, "boardColorButton"));
	gnoBang->backgroundColorButton=GTK_COLOR_BUTTON(gtk_builder_get_object(builder, "backgroundColorButton"));
	gnoBang->hintColorButton=GTK_COLOR_BUTTON(gtk_builder_get_object(builder, "hintColorButton"));
	gnoBang->playerColorButton[0]=GTK_COLOR_BUTTON(gtk_builder_get_object(builder, "player1ColorButton"));
	gnoBang->playerColorButton[1]=GTK_COLOR_BUTTON(gtk_builder_get_object(builder, "player2ColorButton"));
	
	gtk_builder_connect_signals(builder, gnoBang);

	g_object_unref(G_OBJECT(builder));
	
	return 0;
}


/************************************************************************
 *																		*
 * the exit callback												 	*
 *  																	*
 ************************************************************************/

gboolean exitCB(GtkObject *gobj)
{
	if(goGame->GameStatus==GAME_RUNNING)
		setGameStatus(GAME_PAUSED);
	
	if(goGame->GameStatus!=GAME_FINISHED && goGame->GameStatus!=GAME_NEW)
	{
		GtkWidget	*dialog;
		gint		rc;
		
		dialog=gtk_message_dialog_new_with_markup(gnoBang->window,
	            GTK_DIALOG_DESTROY_WITH_PARENT,
	            GTK_MESSAGE_QUESTION,
	            GTK_BUTTONS_YES_NO,
	            "<span size=\"large\">Do you want to quit GnoBang?</span>");
		
		gtk_window_set_title(GTK_WINDOW(dialog), "Quit GnoBang?");
		rc=gtk_dialog_run(GTK_DIALOG(dialog));
		gtk_widget_destroy(dialog);
		
		if(rc==GTK_RESPONSE_NO)
			return TRUE;
	}
	
	playSound(GOODBYE_SOUND, TRUE);
  
	gtk_main_quit();

	freeBoard();
	destroyAll();
	destroyCursors();

	soundSystemCleanup();
	
	return FALSE;
}


/************************************************************************
 *																		*
 * show an error message and write g_warning						 	*
 *  																	*
 ************************************************************************/

void showErrorMessage(const gchar *msg)
{
	GtkWidget  *dialog;
        
	g_warning(msg);
        
	/* create an error message dialog and display modally to the user */
	dialog=gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                  GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, msg);
        
	gtk_window_set_title(GTK_WINDOW(dialog), "Error!");
	gtk_dialog_run(GTK_DIALOG(dialog));      
	gtk_widget_destroy(dialog);         
}


/************************************************************************
 *																		*
 * apply preferences once loaded or changed							 	*
 *  																	*
 ************************************************************************/

void applyPreferences()
{
	/* get the player colors for the labels */
	setcolor(gnoBang->playerColor[0], goGame->Player[0].Color);
	setcolor(gnoBang->playerColor[1], goGame->Player[1].Color);

	/* now set the labels for the players timers */
	char *txt;
	
	txt=g_strdup_printf("<span size=\"large\" color=\"#%s\">%s:</span>", gnoBang->playerColor[0], goGame->Player[0].Name);
	gtk_label_set_markup(gnoBang->playerTimerLabel[0], txt);
	g_free(txt);

	txt=g_strdup_printf("<span size=\"large\" color=\"#%s\">%s:</span>", gnoBang->playerColor[1], goGame->Player[1].Name);
	gtk_label_set_markup(gnoBang->playerTimerLabel[1], txt);
	g_free(txt);
	
	setPlayerTimer(0);
	setPlayerTimer(1);
	
	/* calc new size and than change widget size */
	goGame->Width=(goGame->Columns-1)*FIELD_SIZE+2*BORDER_SIZE+IMAGE_SIZE+2;
	goGame->Height=(goGame->Rows-1)*FIELD_SIZE+2*BORDER_SIZE+IMAGE_SIZE+2; 
	
	/* we destroy all images and everything since the colors may have changed */
	destroyAll();
	
	/* create cursors, ximages, new GCs and redraw the board */
	createCursors();	
	createXImages();

	allocBoard();
	initGCs();
	drawBoard();
	
	/* set min size for drawing area and request resize of window with a size to small */
	gtk_widget_set_size_request(GTK_WIDGET(gnoBang->drawingArea), goGame->Width, goGame->Height);
	gtk_window_resize(gnoBang->window, goGame->Width, goGame->Height);
	
	/* finally call new game to set start player */
	newGame();
}



