/* GnoBang: (c) 2008 by Andreas S. Krebs
 * 
 * This file is part of GnoBang.
 *
 * GnoBang is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GnoBang is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GnoBang.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "gnobang.h"


/************************************************************************
 *																		*
 * callback for help menu item										 	*
 *  																	*
 ************************************************************************/

void helpCB(GtkObject *object)
{
	GtkWidget	*dialog;
	
	dialog=gtk_message_dialog_new_with_markup(gnoBang->window,
            GTK_DIALOG_DESTROY_WITH_PARENT,
            GTK_MESSAGE_OTHER,
            GTK_BUTTONS_OK,
            "<span size=\"large\"><u>How to play GnoBang?</u></span>");
	
	gtk_window_set_title(GTK_WINDOW(dialog), "Help");
	gtk_message_dialog_format_secondary_markup(GTK_MESSAGE_DIALOG(dialog), "<span size=\"large\">Get five in a row to win - that's all ;-)</span>");
	
	gtk_dialog_run(GTK_DIALOG(dialog));
	gtk_widget_destroy(dialog);
}


/************************************************************************
 *																		*
 * callback for launching browser									 	*
 *  																	*
 ************************************************************************/

static void activateUrlCB(GtkAboutDialog *about, const gchar *url, gpointer data)
{
	GdkScreen	*screen=gtk_window_get_screen(gnoBang->window);
	
	if(data!=NULL)
	{
		gchar	*email=g_strdup_printf("%s%s", (char *)data, url);
		
		gnome_url_show_on_screen(email, screen, NULL);
		g_free(email);
	}
	else
		gnome_url_show_on_screen(url, screen, NULL);
}

/************************************************************************
 *																		*
 * callback for about menu item										 	*
 *  																	*
 ************************************************************************/

static char *license=
	"GnoBang is free software: you can redistribute it and/or modify it\n"
	"under the terms of the GNU General Public License as published\n"
	"by the Free Software Foundation, either version 3 of the License,\n"
	"or (at your option) any later version.\n"
	"\n"
	"GnoBang is distributed in the hope that it will be useful, but\n"
	"WITHOUT ANY WARRANTY; without even the implied warranty of\n"
	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
	"See the GNU General Public License for more details.\n"
	"\n"
	"You should have received a copy of the GNU General Public License\n"
	"along with GnoBang.  If not, see <http://www.gnu.org/licenses/>.";

static char *authors[]=
{
	"Andreas S. Krebs <andreas.krebs@web.de>",
	NULL
};

void aboutCB(GtkObject *object)
{
	GdkPixbuf *logo;

	// register callback for link in about dialog
	gtk_about_dialog_set_url_hook(activateUrlCB, NULL, NULL);	
	gtk_about_dialog_set_email_hook(activateUrlCB, "mailto:", NULL);
	
	logo=gdk_pixbuf_new_from_file(GNOBANG_ICON, NULL);
	
	gtk_show_about_dialog(gnoBang->window,
			"title",			"About GnoBang",
			"program-name",		"GnoBang",
			"version",			PACKAGE_VERSION,
			"comments", 		"A Gnome get five in a row game.",
			"copyright",		"Copyright © 2008 Andreas S. Krebs",
			"website",			"http://www.sberk.net/gnobang",
			"license",			license,
			"logo",				logo,
			"authors",			authors,
			NULL);
	
	g_object_unref(logo);
}


